# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`iptables`](#iptables): Manage iptables with default rule optimization and a failsafe fallback mode
* [`iptables::install`](#iptables--install): Install the IPTables and IP6Tables components
* [`iptables::rules::base`](#iptables--rules--base): **NOTE: THIS IS A [PRIVATE](https://github.com/puppetlabs/puppetlabs-stdlib#assert_private) CLASS**  Set up the basic iptables rules pertinen
* [`iptables::rules::default_drop`](#iptables--rules--default_drop): **NOTE: THIS IS A [PRIVATE](https://github.com/puppetlabs/puppetlabs-stdlib#assert_private) CLASS**  Manage the default policy settings of th
* [`iptables::rules::mod_recent`](#iptables--rules--mod_recent): A wrapper for managing the xt_recent portion of iptables settings  It is mainly meant to be a helper class but can be used alone if required.
* [`iptables::rules::prevent_localhost_spoofing`](#iptables--rules--prevent_localhost_spoofing): Add rules that prevent external parties from being able to send spoofed packets to your system from ::1  The sysctl setting for rp_filter han
* [`iptables::rules::scanblock`](#iptables--rules--scanblock): Provide a method for setting up an iptables electric fence  Any host that makes it past all of your allow rules will be added to the ban list
* [`iptables::service`](#iptables--service): Manage the IPTables and IP6Tables services  This also installs fallback startup scripts that come into play should the regular processes fail

### Defined types

* [`iptables::listen::all`](#iptables--listen--all): Allow all protocols to all ports from a select set of networks
* [`iptables::listen::icmp`](#iptables--listen--icmp): This provides a simple way to allow ICMP ports into the system.
* [`iptables::listen::tcp_stateful`](#iptables--listen--tcp_stateful): Allow access to specific ports from specific hosts or networks
* [`iptables::listen::udp`](#iptables--listen--udp): Expose UDP ports to a set of hosts
* [`iptables::ports`](#iptables--ports): A define to allow for the standardization of the  iptables::ports syntax across modules
* [`iptables::rule`](#iptables--rule): Add rules to the IPTables configuration file   ### Result:   *filter  :INPUT DROP [0:0]  :FORWARD DROP [0:0]  :OUTPUT ACCEPT [0:0]  :LOCAL-IN

### Resource types

* [`ip6tables_optimize`](#ip6tables_optimize): A name variable, doesn't really do anything
* [`iptables_default_policy`](#iptables_default_policy): Manage the default policy on iptables tables built-in chains
* [`iptables_optimize`](#iptables_optimize): The path to the target file to be optimized. Mainly used for ensuring that the file comes after the optimization.
* [`iptables_rule`](#iptables_rule): Authoritatively manage iptables rules.  This type is atomic, either all rules work, or the old rules are preserved.
* [`xt_recent`](#xt_recent): Sets the various options on the running xt_recent kernel module.  If the module needs to be loaded, attempts to load the module.

### Functions

* [`iptables::slice_ports`](#iptables--slice_ports): Split a stringified Iptables::DestPort into an Array that contain groupings of `max_length` size.
* [`iptables::use_firewalld`](#iptables--use_firewalld): Returns ``true`` if the client can/should use firewalld

### Data types

* [`Iptables::ApplyTo`](#Iptables--ApplyTo): Valid families to which rules should apply
* [`Iptables::DestPort`](#Iptables--DestPort): An ``iptables_rule`` compatible port range or Array
* [`Iptables::PortRange`](#Iptables--PortRange): An iptables-compatible Port Range

## Classes

### <a name="iptables"></a>`iptables`

----------

> It is **highly recommended** that you place this module in ``firewalld``
> mode if the underlying system supports it.
>
> You can do this by setting ``iptables::use_firewalld: true`` in Hiera

----------

This class will detect conflicts with the SIMP option
``simp_options::firewall`` and, if necessary, cease management of IPTables in
the case of a conflict.

In particular, this means that if ``simp_options::firewall`` is ``false``,
but you have included this class, it will refuse to manage IPTables and will
instead raise a warning.

If the ``simp_options::firewall`` variable is not present, the module will
manage IPTables as expected.

#### Parameters

The following parameters are available in the `iptables` class:

* [`enable`](#-iptables--enable)
* [`use_firewalld`](#-iptables--use_firewalld)
* [`ensure`](#-iptables--ensure)
* [`ipv6`](#-iptables--ipv6)
* [`class_debug`](#-iptables--class_debug)
* [`optimize_rules`](#-iptables--optimize_rules)
* [`precise_match`](#-iptables--precise_match)
* [`ignore`](#-iptables--ignore)
* [`default_rules`](#-iptables--default_rules)
* [`scanblock`](#-iptables--scanblock)
* [`prevent_localhost_spoofing`](#-iptables--prevent_localhost_spoofing)
* [`ports`](#-iptables--ports)

##### <a name="-iptables--enable"></a>`enable`

Data type: `Variant[Enum['ignore','firewalld'],Boolean]`

Enable IPTables

* If set to ``true`` will **enable** management of IPTables
* If set to ``false`` will **disable** IPTables completely
* If set to ``ignore`` will stop managing IPTables

Default value: `simplib::lookup('simp_options::firewall', { 'default_value' => true })`

##### <a name="-iptables--use_firewalld"></a>`use_firewalld`

Data type: `Boolean`

Explicitly enable management via ``simp_firewalld``

* Systems that do not have ``firewalld`` installed will fall back to ``iptables``

Default value: `iptables::use_firewalld($enable)`

##### <a name="-iptables--ensure"></a>`ensure`

Data type: `String`

The state that the ``package`` resources should target

* May take any value acceptable to the native ``package`` resource
  ``ensure`` parameter

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

##### <a name="-iptables--ipv6"></a>`ipv6`

Data type: `Boolean`

Also manage IP6Tables

Default value: `true`

##### <a name="-iptables--class_debug"></a>`class_debug`

Data type: `Boolean`

Print messages regarding rule comparisons

Default value: `false`

##### <a name="-iptables--optimize_rules"></a>`optimize_rules`

Data type: `Boolean`

Run the inbuilt iptables rule optimizer to collapse the rules down to as
small as is reasonably possible without reordering

* IPSets have been incorporated via the `firewalld` module

Default value: `true`

##### <a name="-iptables--precise_match"></a>`precise_match`

Data type: `Boolean`

Instead of matching rule counts, perform a more precise match against the
running and to-be-applied rules. You may find that minor changes, such as a
simple netmask change will not be enforced without enabling this option.

* NOTE: You **MUST** use the exact same syntax that will be returned by
  `iptables-save` and `ip6tables-save` if you use this option!
* For example, you cannot write `echo-request` for an ICMP echo match, you
  must instead use `8`.

Default value: `false`

##### <a name="-iptables--ignore"></a>`ignore`

Data type: `Array[String[1]]`

Regular expressions that you would like to match in order to preserve
running rules

* This modifies the behavior of the ``iptables_optimize`` Type.
* Do **not** include the beginning and ending ``/`` but **do** include an
  end or beginning of word marker (``^`` and/or ``$``) if appropriate

Default value: `[]`

##### <a name="-iptables--default_rules"></a>`default_rules`

Data type: `Boolean`

Enable the usual set of default deny rules that you would expect to see on
most systems

* Uses the following expectations of rule ordering (not enforced):
    * 1     -> ``ESTABLISHED`` and ``RELATED`` rules
    * 2-5   -> Standard ``ACCEPT`` and ``DENY`` rules
    * 6-10  -> ``JUMP`` to other rule sets
    * 11-20 -> Pure ``ACCEPT`` rules
    * 22-30 -> ``LOG`` and ``REJECT`` rules

Default value: `true`

##### <a name="-iptables--scanblock"></a>`scanblock`

Data type: `Boolean`

Enable a technique for setting up port-based triggers that will block
anyone connecting to the system for an hour after connection to a forbidden
port

Default value: `false`

##### <a name="-iptables--prevent_localhost_spoofing"></a>`prevent_localhost_spoofing`

Data type: `Boolean`

Add rules to ``PREROUTING`` that will prevent spoofed packets from
``localhost`` addresses from reaching your system

Default value: `true`

##### <a name="-iptables--ports"></a>`ports`

Data type: `Optional[Hash]`

A hash with structure as defined below that will open ports based on the
structure of the hash.
@example An example section of hieradata:
  iptables::ports:
    defaults:
      apply_to: ipv4
    80:
    53:
      proto: udp
    443:
      apply_to: ipv6

Default value: `undef`

### <a name="iptables--install"></a>`iptables::install`

Install the IPTables and IP6Tables components

#### Parameters

The following parameters are available in the `iptables::install` class:

* [`ipv4_package`](#-iptables--install--ipv4_package)
* [`ipv6_package`](#-iptables--install--ipv6_package)

##### <a name="-iptables--install--ipv4_package"></a>`ipv4_package`

Data type: `String[1]`

The package used to manage ipv4 rules

* Default from module data

##### <a name="-iptables--install--ipv6_package"></a>`ipv6_package`

Data type: `String[1]`

The package used to manage ipv6 rules

* Default from module data

### <a name="iptables--rules--base"></a>`iptables::rules::base`

**NOTE: THIS IS A [PRIVATE](https://github.com/puppetlabs/puppetlabs-stdlib#assert_private) CLASS**

Set up the basic iptables rules pertinent to system security

The rules defined in here follow the following suggestion:
* 1     -> ESTABLISHED,RELATED rules.
* 2-5   -> Standard ACCEPT/DENY rules.
* 6-10  -> Jumps to other rule sets.
* 11-20 -> Pure accept rules.
* 22-30 -> Logging and rejection rules.

#### Parameters

The following parameters are available in the `iptables::rules::base` class:

* [`allow_ping`](#-iptables--rules--base--allow_ping)
* [`drop_broadcast`](#-iptables--rules--base--drop_broadcast)
* [`drop_loopback`](#-iptables--rules--base--drop_loopback)
* [`drop_multicast`](#-iptables--rules--base--drop_multicast)
* [`force_local_input`](#-iptables--rules--base--force_local_input)

##### <a name="-iptables--rules--base--allow_ping"></a>`allow_ping`

Data type: `Boolean`

Allow ICMP type 8 (ping) packets into the host

* This is enabled by default for RFC 1122 compliance

@see https://tools.ietf.org/html/rfc1122#page-42 RFC 1122 Section 3.2.2.6

Default value: `true`

##### <a name="-iptables--rules--base--drop_broadcast"></a>`drop_broadcast`

Data type: `Boolean`

Drop all broadcast traffic to this host

Default value: `true`

##### <a name="-iptables--rules--base--drop_loopback"></a>`drop_loopback`

Data type: `Boolean`

Drop all loopback traffic to this host

@see https://tools.ietf.org/html/rfc1122#page-31 RFC 1122 Section 3.2.1.3(g)

Default value: `true`

##### <a name="-iptables--rules--base--drop_multicast"></a>`drop_multicast`

Data type: `Boolean`

Drop all multicast traffic to this host

Default value: `true`

##### <a name="-iptables--rules--base--force_local_input"></a>`force_local_input`

Data type: `Boolean`

Require that all traffic traverse the LOCAL-INPUT chain

* If set to `false`, will put LOCAL-INPUT at the bottom of the INPUT
  traversal stack so that other chains may easily be added above.

Default value: `true`

### <a name="iptables--rules--default_drop"></a>`iptables::rules::default_drop`

**NOTE: THIS IS A [PRIVATE](https://github.com/puppetlabs/puppetlabs-stdlib#assert_private) CLASS**

Manage the default policy settings of the built in chains.

Given that there is a well-defined, and limited, set of built-in chains this
class fully enumerates the combinations to maximize readability.

* Setting any parameter to `true` will activate the DROP condition.
* Setting any parameter to `false` will activate the ACCEPT condition.
* Leaving a parameter unset will not change the state of the system.

NOTE: If you need different settings for IPv6 and IPv4 then you will need to
create your own resources

#### Parameters

The following parameters are available in the `iptables::rules::default_drop` class:

* [`filter_input`](#-iptables--rules--default_drop--filter_input)
* [`filter_forward`](#-iptables--rules--default_drop--filter_forward)
* [`filter_output`](#-iptables--rules--default_drop--filter_output)

##### <a name="-iptables--rules--default_drop--filter_input"></a>`filter_input`

Data type: `Optional[Boolean]`



Default value: `undef`

##### <a name="-iptables--rules--default_drop--filter_forward"></a>`filter_forward`

Data type: `Optional[Boolean]`



Default value: `undef`

##### <a name="-iptables--rules--default_drop--filter_output"></a>`filter_output`

Data type: `Optional[Boolean]`



Default value: `undef`

### <a name="iptables--rules--mod_recent"></a>`iptables::rules::mod_recent`

A wrapper for managing the xt_recent portion of iptables settings

It is mainly meant to be a helper class but can be used alone if
required.

#### Parameters

The following parameters are available in the `iptables::rules::mod_recent` class:

* [`notify_iptables`](#-iptables--rules--mod_recent--notify_iptables)
* [`ip_list_tot`](#-iptables--rules--mod_recent--ip_list_tot)
* [`ip_pkt_list_tot`](#-iptables--rules--mod_recent--ip_pkt_list_tot)
* [`ip_list_hash_size`](#-iptables--rules--mod_recent--ip_list_hash_size)
* [`ip_list_perms`](#-iptables--rules--mod_recent--ip_list_perms)
* [`ip_list_uid`](#-iptables--rules--mod_recent--ip_list_uid)
* [`ip_list_gid`](#-iptables--rules--mod_recent--ip_list_gid)

##### <a name="-iptables--rules--mod_recent--notify_iptables"></a>`notify_iptables`

Data type: `Boolean`

Notify the IPTables service when complete

Default value: `true`

##### <a name="-iptables--rules--mod_recent--ip_list_tot"></a>`ip_list_tot`

Data type: `Integer[0]`

The number of addresses remembered per table

*This effectively becomes the maximum size of your ban list
* Be aware that more addresses means more load on your system

Default value: `200`

##### <a name="-iptables--rules--mod_recent--ip_pkt_list_tot"></a>`ip_pkt_list_tot`

Data type: `Integer[0]`

The number of packets per address remembered

Default value: `20`

##### <a name="-iptables--rules--mod_recent--ip_list_hash_size"></a>`ip_list_hash_size`

Data type: `Integer[0]`

Hash table size

* 0 means to calculate it based on ``ip_list_tot``

Default value: `0`

##### <a name="-iptables--rules--mod_recent--ip_list_perms"></a>`ip_list_perms`

Data type: `String`

Permissions for ``/proc/net/xt_recent/*`` files

Default value: `'0640'`

##### <a name="-iptables--rules--mod_recent--ip_list_uid"></a>`ip_list_uid`

Data type: `Integer[0]`

Numerical UID for ownership of ``/proc/net/xt_recent/*`` files

Default value: `0`

##### <a name="-iptables--rules--mod_recent--ip_list_gid"></a>`ip_list_gid`

Data type: `Integer[0]`

Numerical GID for ownership of ``/proc/net/xt_recent/*`` files

Default value: `0`

### <a name="iptables--rules--prevent_localhost_spoofing"></a>`iptables::rules::prevent_localhost_spoofing`

Add rules that prevent external parties from being able to send spoofed
packets to your system from ::1

The sysctl setting for rp_filter handles this for IPv4

### <a name="iptables--rules--scanblock"></a>`iptables::rules::scanblock`

Provide a method for setting up an iptables electric fence

Any host that makes it past all of your allow rules will be
added to the ban list.

------------------------------------------------------------------------

> **WARNING**
>
> If you enable this, be sure to enable your IPTables rules prior to
> connecting with a client or you're likely to **completely deny** your
> internal hosts.
>
> **WARNING**

------------------------------------------------------------------------

**NOTE:** Changing **any** of the ``ip_*`` variables will cause the iptables
service to be triggered. This is because the variables cannot take
effect until the iptables rules are reset.

## Management

Details on managing xt_recent can be found in ``iptables(8)``. The following
are just some useful commands.

* Add address to list
  ``echo +addr >/proc/net/xt_recent/LIST_NAME``

* Remove address from list
  ``echo -addr >/proc/net/xt_recent/LIST_NAME``

* Remove all address from list
  ``echo / >/proc/net/xt_recent/LIST_NAME``

* **See also**
  * http://www.thatsgeeky.com/2011/01/limiting-brute-force-attacks-with-iptables/
    * Limiting Brute Force Attacks with IPTables

#### Parameters

The following parameters are available in the `iptables::rules::scanblock` class:

* [`enable`](#-iptables--rules--scanblock--enable)
* [`seconds`](#-iptables--rules--scanblock--seconds)
* [`hitcount`](#-iptables--rules--scanblock--hitcount)
* [`set_rttl`](#-iptables--rules--scanblock--set_rttl)
* [`update_interval`](#-iptables--rules--scanblock--update_interval)
* [`logs_per_minute`](#-iptables--rules--scanblock--logs_per_minute)
* [`ip_list_tot`](#-iptables--rules--scanblock--ip_list_tot)
* [`ip_pkt_list_tot`](#-iptables--rules--scanblock--ip_pkt_list_tot)
* [`ip_list_hash_size`](#-iptables--rules--scanblock--ip_list_hash_size)
* [`ip_list_perms`](#-iptables--rules--scanblock--ip_list_perms)
* [`ip_list_uid`](#-iptables--rules--scanblock--ip_list_uid)
* [`ip_list_gid`](#-iptables--rules--scanblock--ip_list_gid)

##### <a name="-iptables--rules--scanblock--enable"></a>`enable`

Data type: `Boolean`

Enable or disable scan blocking

Default value: `true`

##### <a name="-iptables--rules--scanblock--seconds"></a>`seconds`

Data type: `Integer[0]`

Connections from attackers must happen within this number of seconds to be
considered an attack

* Directly relates to hitcount to log and block attackers

Default value: `60`

##### <a name="-iptables--rules--scanblock--hitcount"></a>`hitcount`

Data type: `Integer[0]`

The number of hits that must happen within 'seconds' to be considered an
attack

Default value: `2`

##### <a name="-iptables--rules--scanblock--set_rttl"></a>`set_rttl`

Data type: `Boolean`

Set this if you worry about having external parties DoS your system by
spoofing their IP addresses

Default value: `false`

##### <a name="-iptables--rules--scanblock--update_interval"></a>`update_interval`

Data type: `Integer[0]`

Block attackers for this long (in seconds)

* Connecting systems must not connect for at least this long prior to being
  allowed to reconnect

Default value: `3600`

##### <a name="-iptables--rules--scanblock--logs_per_minute"></a>`logs_per_minute`

Data type: `Integer[0]`

How many logs to send given logs_per_minute connections per minute

* This is mainly so that you don't end up overrunning your log services

Default value: `5`

##### <a name="-iptables--rules--scanblock--ip_list_tot"></a>`ip_list_tot`

Data type: `Integer[0]`

The number of addresses remembered per table

* This effectively becomes the maximum size of your block list
* **NOTE:** Be aware that more addresses means more load on your system

Default value: `200`

##### <a name="-iptables--rules--scanblock--ip_pkt_list_tot"></a>`ip_pkt_list_tot`

Data type: `Integer[0]`

The number of packets per address remembered

Default value: `20`

##### <a name="-iptables--rules--scanblock--ip_list_hash_size"></a>`ip_list_hash_size`

Data type: `Integer[0]`

Hash table size

* ``0`` means to calculate it based on ``ip_list_tot``

Default value: `0`

##### <a name="-iptables--rules--scanblock--ip_list_perms"></a>`ip_list_perms`

Data type: `String`

Permissions for ``/proc/net/xt_recent/*`` files

Default value: `'0640'`

##### <a name="-iptables--rules--scanblock--ip_list_uid"></a>`ip_list_uid`

Data type: `Integer[0]`

Numerical ``UID`` for ownership of ``/proc/net/xt_recent/*`` files

Default value: `0`

##### <a name="-iptables--rules--scanblock--ip_list_gid"></a>`ip_list_gid`

Data type: `Integer[0]`

Numerical ``GID`` for ownership of ``/proc/net/xt_recent/*`` files

Default value: `0`

### <a name="iptables--service"></a>`iptables::service`

Manage the IPTables and IP6Tables services

This also installs fallback startup scripts that come into play should the
regular processes fail to start due to a race condition with DNS.

#### Parameters

The following parameters are available in the `iptables::service` class:

* [`enable`](#-iptables--service--enable)
* [`ipv6`](#-iptables--service--ipv6)

##### <a name="-iptables--service--enable"></a>`enable`

Data type: `Any`

Enable IPTables

* If set to ``false`` with **disable** IPTables completely
* If set to ``ignore`` will stop managing IPTables

Default value: `pick(getvar('iptables::enable'),true)`

##### <a name="-iptables--service--ipv6"></a>`ipv6`

Data type: `Any`

Also manage IP6Tables

Default value: `pick(getvar('iptables::ipv6'),true)`

## Defined types

### <a name="iptables--listen--all"></a>`iptables::listen::all`

Allow all protocols to all ports from a select set of networks

#### Examples

##### Open Access to Hosts ```1.2.3.4`` and ``5.6.7.8``

```puppet
iptables::listen::all { 'example':
  trusted_nets => [ '1.2.3.4', '5.6.7.8' ],
}

### Result

*filter
:INPUT DROP [0:0]
:FORWARD DROP [0:0]
:OUTPUT ACCEPT [0:0]
:LOCAL-INPUT - [0:0]
-A INPUT -j LOCAL-INPUT
-A FORWARD -j LOCAL-INPUT
-A LOCAL-INPUT -p icmp --icmp-type 8 -j ACCEPT
-A LOCAL-INPUT -i lo -j ACCEPT
-A LOCAL-INPUT -m state --state NEW -m tcp -p tcp --dport 22 -j ACCEPT
-A LOCAL-INPUT -s 1.2.3.4 -j ACCEPT
-A LOCAL-INPUT -s 5.6.7.8 -j ACCEPT
-A LOCAL-INPUT -m state --state ESTABLISHED,RELATED -j ACCEPT
-A LOCAL-INPUT -j LOG --log-prefix "IPT:"
-A LOCAL-INPUT -j DROP
COMMIT
```

#### Parameters

The following parameters are available in the `iptables::listen::all` defined type:

* [`first`](#-iptables--listen--all--first)
* [`absolute`](#-iptables--listen--all--absolute)
* [`order`](#-iptables--listen--all--order)
* [`apply_to`](#-iptables--listen--all--apply_to)
* [`trusted_nets`](#-iptables--listen--all--trusted_nets)

##### <a name="-iptables--listen--all--first"></a>`first`

Data type: `Boolean`

Prepend this rule to the rule set

Default value: `false`

##### <a name="-iptables--listen--all--absolute"></a>`absolute`

Data type: `Boolean`

Make sure that this rule is absolutely first, or last, depending on the
setting of ``first``

* If ``first`` is true, this rule will be at the top of the list
* If ``first`` is false, this rule will be at the bottom of the list
* For all ``absolute`` rules, alphabetical sorting still takes place

Default value: `false`

##### <a name="-iptables--listen--all--order"></a>`order`

Data type: `Integer[0]`

The order in which the rule should appear

* 1 is the minimum and 9999999 is the maximum

* The following ordering ranges are suggested (but not enforced):

    * 1     -> ESTABLISHED,RELATED rules
    * 2-5   -> Standard ACCEPT/DENY rules
    * 6-10  -> Jumps to other rule sets
    * 11-20 -> Pure accept rules
    * 22-30 -> Logging and rejection rules

Default value: `11`

##### <a name="-iptables--listen--all--apply_to"></a>`apply_to`

Data type: `Iptables::ApplyTo`

The IPTables network type to which to apply this rule

* ipv4 -> iptables
* ipv6 -> ip6tables
* all  -> Both
* auto -> Try to figure it out from the rule, will **not** pick ``all``

Default value: `'auto'`

##### <a name="-iptables--listen--all--trusted_nets"></a>`trusted_nets`

Data type: `Simplib::Netlist`

Client networks that should be allowed

Set to ``any`` to allow all networks

Default value: `simplib::lookup('simp_options::trusted_nets', { 'default_value' => ['127.0.0.1'] })`

### <a name="iptables--listen--icmp"></a>`iptables::listen::icmp`

This provides a simple way to allow ICMP ports into the system.

* **See also**
  * iptables(8)

#### Examples

##### Allow ``ping`` From ``1.2.3.4`` and ``5.6.7.8``

```puppet
iptables::listen::icmp { "example":
  trusted_nets => [ "1.2.3.4", "5.6.7.8" ],
  icmp_type => '8'
}

### Result

*filter
:INPUT DROP [0:0]
:FORWARD DROP [0:0]
:OUTPUT ACCEPT [0:0]
:LOCAL-INPUT - [0:0]
-A INPUT -j LOCAL-INPUT
-A FORWARD -j LOCAL-INPUT
-A LOCAL-INPUT -p icmp --icmp-type 8 -j ACCEPT
-A LOCAL-INPUT -i lo -j ACCEPT
-A LOCAL-INPUT -m state --state NEW -m tcp -p tcp --dport 22 -j ACCEPT
-A LOCAL-INPUT -p icmp -s 1.2.3.4 --icmp-type 8 -j ACCEPT
-A LOCAL-INPUT -p icmp -s 5.6.7.8 --icmp-type 8 -j ACCEPT
-A LOCAL-INPUT -m state --state ESTABLISHED,RELATED -j ACCEPT
-A LOCAL-INPUT -j LOG --log-prefix "IPT:"
-A LOCAL-INPUT -j DROP
COMMIT
```

#### Parameters

The following parameters are available in the `iptables::listen::icmp` defined type:

* [`icmp_types`](#-iptables--listen--icmp--icmp_types)
* [`first`](#-iptables--listen--icmp--first)
* [`absolute`](#-iptables--listen--icmp--absolute)
* [`order`](#-iptables--listen--icmp--order)
* [`apply_to`](#-iptables--listen--icmp--apply_to)
* [`trusted_nets`](#-iptables--listen--icmp--trusted_nets)

##### <a name="-iptables--listen--icmp--icmp_types"></a>`icmp_types`

Data type: `Variant[Array[String],String]`

The iptables-compatible ICMP types that should be allowed

* You can list the ICMP types with ``iptables -p icmp -h``
* Set to ``any`` to allow **all** ICMP types

##### <a name="-iptables--listen--icmp--first"></a>`first`

Data type: `Boolean`

Prepend this rule to the rule set

Default value: `false`

##### <a name="-iptables--listen--icmp--absolute"></a>`absolute`

Data type: `Boolean`

Make sure that this rule is absolutely first, or last, depending on the
setting of ``first``

* If ``first`` is true, this rule will be at the top of the list
* If ``first`` is false, this rule will be at the bottom of the list
* For all ``absolute`` rules, alphabetical sorting still takes place

Default value: `false`

##### <a name="-iptables--listen--icmp--order"></a>`order`

Data type: `Integer[0]`

The order in which the rule should appear

* 1 is the minimum and 9999999 is the maximum

* The following ordering ranges are suggested (but not enforced):

    * 1     -> ESTABLISHED,RELATED rules
    * 2-5   -> Standard ACCEPT/DENY rules
    * 6-10  -> Jumps to other rule sets
    * 11-20 -> Pure accept rules
    * 22-30 -> Logging and rejection rules

Default value: `11`

##### <a name="-iptables--listen--icmp--apply_to"></a>`apply_to`

Data type: `Iptables::ApplyTo`

The IPTables network type to which to apply this rule

* ipv4 -> iptables
* ipv6 -> ip6tables
* all  -> Both
* auto -> Try to figure it out from the rule, will **not** pick ``all``

Default value: `'auto'`

##### <a name="-iptables--listen--icmp--trusted_nets"></a>`trusted_nets`

Data type: `Simplib::Netlist`

Client networks that should be allowed

Set to ``any`` to allow all networks

Default value: `simplib::lookup('simp_options::trusted_nets', { 'default_value' => ['127.0.0.1'] })`

### <a name="iptables--listen--tcp_stateful"></a>`iptables::listen::tcp_stateful`

Allow access to specific ports from specific hosts or networks

#### Examples

##### Provide Access to Specific Ports

```puppet
iptables::listen::tcp_stateful { 'example':
  trusted_nets => [ '1.2.3.4', '5.6.7.8' ],
  dports => [ 5, '1024:65535' ]
}

### Result

*filter
:INPUT DROP [0:0]
:FORWARD DROP [0:0]
:OUTPUT ACCEPT [0:0]
:LOCAL-INPUT - [0:0]
-A INPUT -j LOCAL-INPUT
-A FORWARD -j LOCAL-INPUT
-A LOCAL-INPUT -p icmp --icmp-type 8 -j ACCEPT
-A LOCAL-INPUT -i lo -j ACCEPT
-A LOCAL-INPUT -m state --state NEW -m tcp -p tcp --dport 22 -j ACCEPT
-A LOCAL-INPUT -m state --state NEW -m tcp -p tcp -s 1.2.3.4 --dport 5 -j ACCEPT
-A LOCAL-INPUT -m state --state NEW -m tcp -p tcp -s 5.6.7.8 --dport 5 -j ACCEPT
-A LOCAL-INPUT -m state --state NEW -m tcp -p tcp -s 1.2.3.4 --dport 1024:65535 -j ACCEPT
-A LOCAL-INPUT -m state --state NEW -m tcp -p tcp -s 5.6.7.8 --dport 1024:65535 -j ACCEPT
-A LOCAL-INPUT -m state --state ESTABLISHED,RELATED -j ACCEPT
-A LOCAL-INPUT -j LOG --log-prefix "IPT:"
-A LOCAL-INPUT -j DROP
COMMIT
```

#### Parameters

The following parameters are available in the `iptables::listen::tcp_stateful` defined type:

* [`dports`](#-iptables--listen--tcp_stateful--dports)
* [`first`](#-iptables--listen--tcp_stateful--first)
* [`absolute`](#-iptables--listen--tcp_stateful--absolute)
* [`order`](#-iptables--listen--tcp_stateful--order)
* [`apply_to`](#-iptables--listen--tcp_stateful--apply_to)
* [`trusted_nets`](#-iptables--listen--tcp_stateful--trusted_nets)

##### <a name="-iptables--listen--tcp_stateful--dports"></a>`dports`

Data type: `Iptables::DestPort`

The ports that you want to expose

##### <a name="-iptables--listen--tcp_stateful--first"></a>`first`

Data type: `Boolean`

Prepend this rule to the rule set

Default value: `false`

##### <a name="-iptables--listen--tcp_stateful--absolute"></a>`absolute`

Data type: `Boolean`

Make sure that this rule is absolutely first, or last, depending on the
setting of ``first``

* If ``first`` is true, this rule will be at the top of the list
* If ``first`` is false, this rule will be at the bottom of the list
* For all ``absolute`` rules, alphabetical sorting still takes place

Default value: `false`

##### <a name="-iptables--listen--tcp_stateful--order"></a>`order`

Data type: `Integer[0]`

The order in which the rule should appear

* 1 is the minimum and 9999999 is the maximum

* The following ordering ranges are suggested (but not enforced):

    * 1     -> ESTABLISHED,RELATED rules
    * 2-5   -> Standard ACCEPT/DENY rules
    * 6-10  -> Jumps to other rule sets
    * 11-20 -> Pure accept rules
    * 22-30 -> Logging and rejection rules

Default value: `11`

##### <a name="-iptables--listen--tcp_stateful--apply_to"></a>`apply_to`

Data type: `Iptables::ApplyTo`

The IPTables network type to which to apply this rule

* ipv4 -> iptables
* ipv6 -> ip6tables
* all  -> Both
* auto -> Try to figure it out from the rule, will **not** pick ``all``

Default value: `'auto'`

##### <a name="-iptables--listen--tcp_stateful--trusted_nets"></a>`trusted_nets`

Data type: `Simplib::Netlist`

Client networks that should be allowed

Set to ``any`` to allow all networks

Default value: `simplib::lookup('simp_options::trusted_nets', { 'default_value' => ['127.0.0.1'] })`

### <a name="iptables--listen--udp"></a>`iptables::listen::udp`

Expose UDP ports to a set of hosts

#### Examples

##### Allow UDP Access to ``1.2.3.4`` and ``5.6.7.8``

```puppet
iptables::listen::udp { 'example':
  trusted_nets => [ '1.2.3.4', '5.6.7.8' ],
  dports       => [ 5, '1024:65535' ]
}

### Result

*filter
:INPUT DROP [0:0]
:FORWARD DROP [0:0]
:OUTPUT ACCEPT [0:0]
:LOCAL-INPUT - [0:0]
-A INPUT -j LOCAL-INPUT
-A FORWARD -j LOCAL-INPUT
-A LOCAL-INPUT -p icmp --icmp-type 8 -j ACCEPT
-A LOCAL-INPUT -i lo -j ACCEPT
-A LOCAL-INPUT -m state --state NEW -m tcp -p tcp --dport 22 -j ACCEPT
-A LOCAL-INPUT -p udp -s 1.2.3.4 --dport 5 -j ACCEPT
-A LOCAL-INPUT -p udp -s 5.6.7.8 --dport 5 -j ACCEPT
-A LOCAL-INPUT -p udp -s 1.2.3.4 --dport 1024:65535 -j ACCEPT
-A LOCAL-INPUT -p udp -s 5.6.7.8 --dport 1024:65535 -j ACCEPT
-A LOCAL-INPUT -m state --state ESTABLISHED,RELATED -j ACCEPT
-A LOCAL-INPUT -j LOG --log-prefix "IPT:"
-A LOCAL-INPUT -j DROP
COMMIT
```

#### Parameters

The following parameters are available in the `iptables::listen::udp` defined type:

* [`dports`](#-iptables--listen--udp--dports)
* [`first`](#-iptables--listen--udp--first)
* [`absolute`](#-iptables--listen--udp--absolute)
* [`order`](#-iptables--listen--udp--order)
* [`apply_to`](#-iptables--listen--udp--apply_to)
* [`trusted_nets`](#-iptables--listen--udp--trusted_nets)

##### <a name="-iptables--listen--udp--dports"></a>`dports`

Data type: `Iptables::DestPort`

The ports that you want to expose

##### <a name="-iptables--listen--udp--first"></a>`first`

Data type: `Boolean`

Prepend this rule to the rule set

Default value: `false`

##### <a name="-iptables--listen--udp--absolute"></a>`absolute`

Data type: `Boolean`

Make sure that this rule is absolutely first, or last, depending on the
setting of ``first``

* If ``first`` is true, this rule will be at the top of the list
* If ``first`` is false, this rule will be at the bottom of the list
* For all ``absolute`` rules, alphabetical sorting still takes place

Default value: `false`

##### <a name="-iptables--listen--udp--order"></a>`order`

Data type: `Integer[0]`

The order in which the rule should appear

* 1 is the minimum and 9999999 is the maximum

* The following ordering ranges are suggested (but not enforced):

    * 1     -> ESTABLISHED,RELATED rules
    * 2-5   -> Standard ACCEPT/DENY rules
    * 6-10  -> Jumps to other rule sets
    * 11-20 -> Pure accept rules
    * 22-30 -> Logging and rejection rules

Default value: `11`

##### <a name="-iptables--listen--udp--apply_to"></a>`apply_to`

Data type: `Iptables::ApplyTo`

The IPTables network type to which to apply this rule

* ipv4 -> iptables
* ipv6 -> ip6tables
* all  -> Both
* auto -> Try to figure it out from the rule, will **not** pick ``all``

Default value: `'auto'`

##### <a name="-iptables--listen--udp--trusted_nets"></a>`trusted_nets`

Data type: `Simplib::Netlist`

Client networks that should be allowed

Set to ``any`` to allow all networks

Default value: `simplib::lookup('simp_options::trusted_nets', { 'default_value' => ['127.0.0.1'] })`

### <a name="iptables--ports"></a>`iptables::ports`

A define to allow for the standardization of the
 iptables::ports syntax across modules

#### Parameters

The following parameters are available in the `iptables::ports` defined type:

* [`ports`](#-iptables--ports--ports)

##### <a name="-iptables--ports--ports"></a>`ports`

Data type: `Hash`

A hash with structure as defined below that will open ports based on the
structure of the hash.
@example An example section of hieradata:
  iptables::ports:
    defaults:
      apply_to: ipv4
    80:
    53:
      proto: udp
    443:
      apply_to: ipv6
    514:
      proto:
        - udp
        - tcp

### <a name="iptables--rule"></a>`iptables::rule`

Add rules to the IPTables configuration file

 ### Result:

 *filter
 :INPUT DROP [0:0]
 :FORWARD DROP [0:0]
 :OUTPUT ACCEPT [0:0]
 :LOCAL-INPUT - [0:0]
 -A INPUT -j LOCAL-INPUT
 -A FORWARD -j LOCAL-INPUT
 -A LOCAL-INPUT -p icmp --icmp-type 8 -j ACCEPT
 -A LOCAL-INPUT -i lo -j ACCEPT
 -A LOCAL-INPUT -m state --state NEW -m tcp -p tcp --dport 22 -j ACCEPT
 -A LOCAL-INPUT -m state --state NEW -m tcp -p tcp -s 1.2.3.4 --dport 1024:65535 -j ACCEPT
 -A LOCAL-INPUT -m state --state ESTABLISHED,RELATED -j ACCEPT
 -A LOCAL-INPUT -j LOG --log-prefix "IPT:"
 -A LOCAL-INPUT -j DROP
 COMMIT

#### Examples

##### Add a TCP Allow Rule

```puppet
iptables::rule { 'example':
  content => '-A LOCAL-INPUT -m state --state NEW -m tcp -p tcp -s 1.2.3.4 --dport 1024:65535 -j ACCEPT'
}
```

#### Parameters

The following parameters are available in the `iptables::rule` defined type:

* [`content`](#-iptables--rule--content)
* [`table`](#-iptables--rule--table)
* [`first`](#-iptables--rule--first)
* [`absolute`](#-iptables--rule--absolute)
* [`order`](#-iptables--rule--order)
* [`header`](#-iptables--rule--header)
* [`apply_to`](#-iptables--rule--apply_to)

##### <a name="-iptables--rule--content"></a>`content`

Data type: `String`

The **exact** content of the rule that should be added

##### <a name="-iptables--rule--table"></a>`table`

Data type: `String`

The name of the table you are adding to

* Usual names include (but are not limited to):

    * filter
    * mangle
    * nat
    * raw
    * security

Default value: `'filter'`

##### <a name="-iptables--rule--first"></a>`first`

Data type: `Boolean`

Prepend this rule to the rule set

Default value: `false`

##### <a name="-iptables--rule--absolute"></a>`absolute`

Data type: `Boolean`

Make sure that this rule is absolutely first, or last, depending on the
setting of ``first``

* If ``first`` is true, this rule will be at the top of the list
* If ``first`` is false, this rule will be at the bottom of the list
* For all ``absolute`` rules, alphabetical sorting still takes place

Default value: `false`

##### <a name="-iptables--rule--order"></a>`order`

Data type: `Integer[0]`

The order in which the rule should appear

* 1 is the minimum and 9999999 is the maximum

* The following ordering ranges are suggested (but not enforced):

    * 1     -> ESTABLISHED,RELATED rules
    * 2-5   -> Standard ACCEPT/DENY rules
    * 6-10  -> Jumps to other rule sets
    * 11-20 -> Pure accept rules
    * 22-30 -> Logging and rejection rules

Default value: `11`

##### <a name="-iptables--rule--header"></a>`header`

Data type: `Boolean`

Automatically add the line header ``-A LOCAL-INPUT``

Default value: `true`

##### <a name="-iptables--rule--apply_to"></a>`apply_to`

Data type: `Iptables::ApplyTo`

The IPTables network type to which to apply this rule

* ipv4 -> iptables
* ipv6 -> ip6tables
* all  -> Both
* auto -> Try to figure it out from the rule, will **not** pick ``all``

Default value: `'auto'`

## Resource types

### <a name="ip6tables_optimize"></a>`ip6tables_optimize`

A name variable, doesn't really do anything

#### Properties

The following properties are available in the `ip6tables_optimize` type.

##### `optimize`

Valid values: `true`, `false`

Whether or not to optimize

Default value: `true`

#### Parameters

The following parameters are available in the `ip6tables_optimize` type.

* [`disable`](#-ip6tables_optimize--disable)
* [`ignore`](#-ip6tables_optimize--ignore)
* [`name`](#-ip6tables_optimize--name)
* [`precise_match`](#-ip6tables_optimize--precise_match)
* [`provider`](#-ip6tables_optimize--provider)

##### <a name="-ip6tables_optimize--disable"></a>`disable`

Valid values: `true`, `false`

This is a way to authoritatively disable the application of the
iptables module.

Default value: `false`

##### <a name="-ip6tables_optimize--ignore"></a>`ignore`

Ignore all *running* iptables rules matching one or more provided Ruby
regexes. The regexes are compared against the jump and chain options, as
well as the interface name of the running rules and excluded from the
synchronization comparison against the new rules.

!!Do not include the beginning and ending slashes in your regular expressions.!!

NOTE: If a rule has been added or removed, this setting ignored and
ip6tables *will* be restarted! If you have services which are
affected by this, make sure that they subscribe to
Service['ip6tables'] and/or Service['ip6tables'] as appropriate.

Examples:
  # Preserve all rules whose chain begins with the word 'foo'
  ignore => '^foo'

  # Preserve all rules whose chain begins with the word 'foo' or
  # ends with the word 'bar'
  ignore => ['^foo','bar$']

##### <a name="-ip6tables_optimize--name"></a>`name`

namevar

A name variable, doesn't really do anything

##### <a name="-ip6tables_optimize--precise_match"></a>`precise_match`

Valid values: `true`, `false`

Instead of matching rule counts, perform a more precise match against the
running and to-be-applied rules. You may find that minor changes, such as
a simple netmask change will not be enforced without enabling this option.

This is enabled by default because it is a more correct approach.

* NOTE: You **MUST** use the exact same syntax that will be returned by
  `ip6tables-save` if you enable this option!
* For example, you cannot write `echo-request` for an ICMP echo match, you
  must instead use `8`.

Default value: `true`

##### <a name="-ip6tables_optimize--provider"></a>`provider`

The specific backend to use for this `ip6tables_optimize` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="iptables_default_policy"></a>`iptables_default_policy`

Manage the default policy on iptables tables built-in chains

#### Properties

The following properties are available in the `iptables_default_policy` type.

##### `policy`

Valid values: `ACCEPT`, `DROP`, `accept`, `drop`

The IPTables JUMP policy to apply

Default value: `DROP`

#### Parameters

The following parameters are available in the `iptables_default_policy` type.

* [`apply_to`](#-iptables_default_policy--apply_to)
* [`chain`](#-iptables_default_policy--chain)
* [`name`](#-iptables_default_policy--name)
* [`provider`](#-iptables_default_policy--provider)
* [`table`](#-iptables_default_policy--table)

##### <a name="-iptables_default_policy--apply_to"></a>`apply_to`

Valid values: `ipv4`, `ipv6`, `all`

What version(s) of iptables to which to apply this rule.
'all' is equivalent to ['ipv4', 'ipv6'] as appropriate.

Default value: `all`

##### <a name="-iptables_default_policy--chain"></a>`chain`

namevar

The targeted chain

##### <a name="-iptables_default_policy--name"></a>`name`

A name of the form <table>:<chain> to which the resource will be applied

##### <a name="-iptables_default_policy--provider"></a>`provider`

The specific backend to use for this `iptables_default_policy` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

##### <a name="-iptables_default_policy--table"></a>`table`

namevar

The table that the chain belongs to

### <a name="iptables_optimize"></a>`iptables_optimize`

The path to the target file to be optimized. Mainly used for ensuring that the file comes after the optimization.

#### Properties

The following properties are available in the `iptables_optimize` type.

##### `optimize`

Valid values: `true`, `false`

Whether or not to optimize

Default value: `true`

#### Parameters

The following parameters are available in the `iptables_optimize` type.

* [`disable`](#-iptables_optimize--disable)
* [`ignore`](#-iptables_optimize--ignore)
* [`name`](#-iptables_optimize--name)
* [`precise_match`](#-iptables_optimize--precise_match)
* [`provider`](#-iptables_optimize--provider)

##### <a name="-iptables_optimize--disable"></a>`disable`

Valid values: `true`, `false`

This is a way to authoritatively disable the application of the
iptables module.

Default value: `false`

##### <a name="-iptables_optimize--ignore"></a>`ignore`

Ignore all *running* iptables rules matching one or more provided Ruby
regexes. The regexes are compared against the jump and chain options, as
well as the interface name of the running rules and excluded from the
synchronization comparison against the new rules.

!!Do not include the beginning and ending slashes in your regular expressions.!!

NOTE: If a rule has been added or removed, this setting ignored and
iptables *will* be restarted! If you have services which are
affected by this, make sure that they subscribe to
Service['iptables'] and/or Service['ip6tables'] as appropriate.

Examples:
  # Preserve all rules whose jump or chain begins with the word 'foo'
  ignore => '^foo'

  # Preserve all rules whose jump or chain begins with the word 'foo' or
  # ends with the word 'bar'
  ignore => ['^foo','bar$']

##### <a name="-iptables_optimize--name"></a>`name`

namevar

The path to the target file to be optimized. Mainly used for ensuring that the file comes after the optimization.

##### <a name="-iptables_optimize--precise_match"></a>`precise_match`

Valid values: `true`, `false`

Instead of matching rule counts, perform a more precise match against the
running and to-be-applied rules. You may find that minor changes, such as
a simple netmask change will not be enforced without enabling this option.

This is enabled by default because it is a more correct approach.

* NOTE: You **MUST** use the exact same syntax that will be returned by
  `iptables-save` if you enable this option!
* For example, you cannot write `echo-request` for an ICMP echo match, you
  must instead use `8`.

Default value: `true`

##### <a name="-iptables_optimize--provider"></a>`provider`

The specific backend to use for this `iptables_optimize` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="iptables_rule"></a>`iptables_rule`

Authoritatively manage iptables rules.  This type is
atomic, either all rules work, or the old rules are
preserved.

#### Properties

The following properties are available in the `iptables_rule` type.

##### `content`

Valid values: `/\w+/`

The content of the rule that should be added

#### Parameters

The following parameters are available in the `iptables_rule` type.

* [`absolute`](#-iptables_rule--absolute)
* [`apply_to`](#-iptables_rule--apply_to)
* [`comment`](#-iptables_rule--comment)
* [`comment_header`](#-iptables_rule--comment_header)
* [`first`](#-iptables_rule--first)
* [`header`](#-iptables_rule--header)
* [`include_comment`](#-iptables_rule--include_comment)
* [`name`](#-iptables_rule--name)
* [`order`](#-iptables_rule--order)
* [`provider`](#-iptables_rule--provider)
* [`resolve`](#-iptables_rule--resolve)
* [`table`](#-iptables_rule--table)

##### <a name="-iptables_rule--absolute"></a>`absolute`

Valid values: `true`, `false`

Set to 'true' if you want the rule to be the absolute
first or last. This is relative and places items in
alphabetical order if multiple absolute first/lasts are
specified.

Default value: `false`

##### <a name="-iptables_rule--apply_to"></a>`apply_to`

Valid values: `ipv4`, `ipv6`, `all`, `auto`

What version(s) of iptables to which to apply this rule.
If set to 'auto' (the default) then we'll try to guess
what you want and default to ['ipv4','ipv6'].

If 'auto' is set then each line will be evaluated as an
independent rule.
- Any rules that have IPv4 addresses will be applied to
  iptables.
- Any rules that have IPv6 addresses will be applied to
  ip6tables.
- All other rules will be applied to *both* utilities.
- If in doubt, split your rules and specify your tables!

Default value: `auto`

##### <a name="-iptables_rule--comment"></a>`comment`

A comment to add to the rule.

The value of $comment_header will be prepended.

Empty comments (no content and no header) will be discarded.

Content will be truncated at 255 characters, including the header.

Default value: `''`

##### <a name="-iptables_rule--comment_header"></a>`comment_header`

A header to prepend to all comments for easy visual rule tracking

Default value: `SIMP:`

##### <a name="-iptables_rule--first"></a>`first`

Valid values: `true`, `false`

Set to 'true' if you want to prepend your rule.

Default value: `false`

##### <a name="-iptables_rule--header"></a>`header`

Valid values: `true`, `false`

Whether or not to auto-include the table LOCAL-INPUT in
the rule.

Default value: `true`

##### <a name="-iptables_rule--include_comment"></a>`include_comment`

Valid values: `true`, `false`, `yes`, `no`

Whether or not to include the value in the $comment paramter

Default value: `true`

##### <a name="-iptables_rule--name"></a>`name`

namevar

The name of the rule. Simply used for creating the unique fragments.

##### <a name="-iptables_rule--order"></a>`order`

Valid values: `/\d+/`

The order in which the rule should appear. 1 is the
minimum and 999 is the max.

Default value: `11`

##### <a name="-iptables_rule--provider"></a>`provider`

The specific backend to use for this `iptables_rule` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="-iptables_rule--resolve"></a>`resolve`

Valid values: `true`, `false`

Whether or not to use DNS resolution to identify hostnames
in IPTables statements.

This should probably be left at :true since it is a rare
scenario and, should you use this, you will want the rule
to go into either iptables or ip6tables correctly.

With this enabled, the IP address that is resolved will be
added to IPTables and not the hostname itself.

Default value: `true`

##### <a name="-iptables_rule--table"></a>`table`

The name of the table that you are adding to.

Default value: `filter`

### <a name="xt_recent"></a>`xt_recent`

Sets the various options on the running xt_recent kernel module.

If the module needs to be loaded, attempts to load the module.

#### Properties

The following properties are available in the `xt_recent` type.

##### `ip_list_gid`

Valid values: `/^\d+$/`

Numerical GID for ownership of /proc/net/xt_recent/* files.

Default value: `0`

##### `ip_list_hash_size`

Valid values: `/^\d+$/`

Hash table size. 0 means to calculate it based on ip_list_tot.

Default value: `0`

##### `ip_list_perms`

Valid values: `/^[0-7]{4}$/`

Permissions for /proc/net/xt_recent/* files.

Default value: `0640`

##### `ip_list_tot`

Valid values: `/^\d+$/`

The number of addresses remembered per table. This effectively
becomes the maximum size of your block list. Be aware that
more addresses means more load on your system.

Default value: `100`

##### `ip_list_uid`

Valid values: `/^\d+$/`

Numerical UID for ownership of /proc/net/xt_recent/* files.

Default value: `0`

##### `ip_pkt_list_tot`

Valid values: `/^\d+$/`

The number of packets per address remembered.

Default value: `20`

#### Parameters

The following parameters are available in the `xt_recent` type.

* [`name`](#-xt_recent--name)
* [`provider`](#-xt_recent--provider)

##### <a name="-xt_recent--name"></a>`name`

namevar

The path to the xt_recent variables to be manipulated

##### <a name="-xt_recent--provider"></a>`provider`

The specific backend to use for this `xt_recent` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

## Functions

### <a name="iptables--slice_ports"></a>`iptables::slice_ports`

Type: Ruby 4.x API

Split a stringified Iptables::DestPort into an Array that contain groupings
of `max_length` size.

#### `iptables::slice_ports(Variant[String,Array[String]] $input, Integer[1] $max_length)`

Split a stringified Iptables::DestPort into an Array that contain groupings
of `max_length` size.

Returns: `Array[Array[String]]` ]

##### `input`

Data type: `Variant[String,Array[String]]`

One or more ports or port ranges, all represented
as strings.

##### `max_length`

Data type: `Integer[1]`

The maximum length of each group.

### <a name="iptables--use_firewalld"></a>`iptables::use_firewalld`

Type: Puppet Language

Returns ``true`` if the client can/should use firewalld

#### `iptables::use_firewalld(Variant[String[1], Boolean] $enable = true)`

Returns ``true`` if the client can/should use firewalld

Returns: `Boolean`

##### `enable`

Data type: `Variant[String[1], Boolean]`

The type of enablement to use

* true      => Do the right thing based on the underlying OS
* false     => Return `false`
* firewalld => Force `firewalld` if available

## Data types

### <a name="Iptables--ApplyTo"></a>`Iptables::ApplyTo`

Valid families to which rules should apply

Alias of `Enum['ipv4', 'ipv6', 'all', 'auto']`

### <a name="Iptables--DestPort"></a>`Iptables::DestPort`

An ``iptables_rule`` compatible port range or Array

Alias of `Variant[Simplib::Port, Iptables::PortRange, Array[Variant[Simplib::Port, Iptables::PortRange]]]`

### <a name="Iptables--PortRange"></a>`Iptables::PortRange`

An iptables-compatible Port Range

Alias of `Pattern['^([0-5]?\d?\d?\d?\d|6[0-4]\d\d\d|65[0-4]\d\d|655[0-2]\d|6553[0-5]):([0-5]?\d?\d?\d?\d|6[0-4]\d\d\d|65[0-4]\d\d|655[0-2]\d|6553[0-5])$']`

